Crate santa_data

Crate santa_data 

Santa Data - Data models and CCL parser for Santa Package Manager

This crate provides:

  • Core data models (Platform, KnownSources, PackageData, etc.)
  • CCL schema definitions (PackageDefinition, SourceDefinition, etc.)
  • CCL parser that handles both simple and complex formats

The parser works around limitations in serde_ccl 0.1.1.

Re-exports

pub use models::*;
pub use schemas::*;

Modules

models
schemas

Enums

CclValue
Represents a parsed CCL value

Functions

parse_ccl
Parse a CCL document into a CclValue
parse_ccl_to
Parse CCL string and deserialize into a specific type
parse_to_hashmap
Parse CCL string into a HashMap where values can be either arrays or objects