Module models

Module models 

Structs

CommandName
Strong type for command names to prevent command/package name confusion
PackageData
Package-specific configuration data
PackageName
Strong type for package names to prevent mixing up with other strings
Platform
SourceName
Strong type for source names to prevent mixing up with other strings

Enums

Arch
Distro
KnownSources
OS

Type Aliases

PackageDataList
Map of package names to their source configurations