ComplexPackageDefinition

Struct ComplexPackageDefinition 

#[non_exhaustive]
pub struct ComplexPackageDefinition { pub description: Option<String>, pub sources: Option<Vec<String>>, pub platforms: Option<Vec<String>>, pub aliases: Option<Vec<String>>, pub source_configs: HashMap<String, SourceSpecificConfig>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
description: Option<String>

Short description of the package

sources: Option<Vec<String>>

List of sources where package is available with same name as key

platforms: Option<Vec<String>>

Platforms where this package is available

aliases: Option<Vec<String>>

Alternative names for search and discovery

source_configs: HashMap<String, SourceSpecificConfig>

Source-specific configurations (flatten other fields)

Implementations

Source

impl ComplexPackageDefinition

pub fn with_sources(sources: Vec<String>) -> Self

Create a new ComplexPackageDefinition with the given sources

pub fn set_platforms(&mut self, platforms: Vec<String>)

Set the platforms for this package definition

pub fn set_aliases(&mut self, aliases: Vec<String>)

Set the aliases for this package definition

pub fn set_description(&mut self, description: String)

Set the description for this package definition

pub fn get_sources(&self) -> Vec<&str>

Get all sources where this package is available

pub fn get_source_config(&self, source: &str) -> Option<&SourceSpecificConfig>

Get source-specific configuration for a source

pub fn is_available_in(&self, source: &str) -> bool

Check if package is available in a specific source