Structs
- Command
Name - Strong type for command names to prevent command/package name confusion
- Package
Data - Package-specific configuration data
- Package
Name - Strong type for package names to prevent mixing up with other strings
- Platform
- Source
Name - Strong type for source names to prevent mixing up with other strings
Enums
Type Aliases
- Package
Data List - Map of package names to their source configurations